function E=edge_detection(I, k)
% E=edge_detection(I, k)
% I: immagine
% k: soglia di salto intensita'
% E: Immagine che evidenzia gli edge

% supponiamo che I sia un'immagine a toni di grigio
[nx, ny]=size(I);
E=zeros(nx, ny); 

for i=1:nx-1
    for j=1:ny-1
  	 val=I(i,j); % intensita' pixel (i,j)
 	 val1=I(i+1, j); %intensita' pixel a destra  
  	 val2=I(i, j+1); % intensita' pixel sotto
  	 d1=val-val1;
   	 d2=val-val2;
  	 if abs(d1)>k | abs(d2)>k
    	 E(i, j)=255; % accendo un pixel
        end
    end
end


